# Common helper libraries for Python Apps

[![PyPI](https://img.shields.io/pypi/v/apphelpers.svg)](https://pypi.python.org/pypi/apphelpers)
[![Travis CI](https://img.shields.io/travis/scrolltech/apphelpers.svg)](https://travis-ci.org/scrolltech/apphelpers)
[![Documentation Status](https://readthedocs.org/projects/apphelpers/badge/?version=latest)](https://apphelpers.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/scrolltech/apphelpers/shield.svg)](https://pyup.io/repos/github/scrolltech/apphelpers/)

Common helper libraries for Python Apps

* Free software: MIT license
* Documentation: https://apphelpers.readthedocs.io.

## Features

* TODO

## Development Setup

```bash
sudo apt-get install postgresql
sudo -u postgres createuser -d  $USERNAME -P
createdb mydb
pip install 'piccolo[postgres]'
```

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [`audreyr/cookiecutter-pypackage`](https://github.com/audreyr/cookiecutter-pypackage) project template.
